// Importing node-modules we need
import { default as Web3 } from "web3";
import { default as contract } from "truffle-contract";

// Importing compiled contracts here
import DNSabi from "../build/contracts/SimpleDNS.json";

// Importing styles
import styles from "./styles/index.scss";

// Making usable abstraction from our artifacts, so we can use it in code.
const SimpleDNS = contract(DNSabi);
let account;

window.App = {
    /**
     * Initializing Web3 provider for our app
     */
    initWeb3: () => {
        if (typeof web3 !== "undefined") web3 = new Web3(web3.currentProvider);
        else
            web3 = new Web3(
                new Web3.providers.HttpProvider("http://localhost:8545")
            );
    },

    /**
     * Initializing our App
     */
    init: () => {
        App.initWeb3();
        // Init your contract here and set web3provider to it.
        SimpleDNS.setProvider(web3.currentProvider);
        web3.eth.getAccounts((err, accounts) => {
            account = accounts[0];
            console.log(account);
        });
    },

    setDomain: () => {
        let domain = document.getElementById("set-domain");

        SimpleDNS.deployed().then(instance => {
            instance.setOwner(domain.value, { from: account });
        });
    },

    getDomain: () => {
        let domain = document.getElementById("get-domain");

        SimpleDNS.deployed().then(instance => {
            instance.getOwner(domain.value).then(res => {
                console.log(res);
            });
        });
    },

    setIPaddr: () => {
        let domain = document.getElementById("domain");
        let ipaddr = document.getElementById("set-ip");

        SimpleDNS.deployed().then(instance => {
            instance.setIp(domain.value, ipaddr.value, { from: account });
        });
    },

    getIPaddr: () => {
        let domain = document.getElementById("get-ip");

        SimpleDNS.deployed().then(instance => {
            instance.getIp(domain.value).then(res => {
                console.log(res);
            });
        });
    }
};

/**
 * Initializing our App on window load
 * 'load' Happens when browser window loads
 */
window.addEventListener("load", () => {
    App.init();
});
